import {useState} from 'react';
import FormControl from '@mui/material/FormControl';
import Input from '@mui/material/Input';
import FormHelperText from '@mui/material/FormHelperText';
import Button from '@mui/material/Button';

import {register, unpack_api_result} from '../api/Api';

function Register(props) {
  const [registrationToken, setRegistrationToken] = useState("");
  const [username, setUsername] = useState("");
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [passwordRepeat, setPasswordRepeat] = useState("");

  const onRegister = () => {
    let input = {
        username,
        email,
        password,
        password_repeat: passwordRepeat
    }

    unpack_api_result(register(registrationToken, input), props.setFlash)
      .then(result => {
        if(result !== undefined) {
          props.onRegistered(result.user);
        }
      });
  }

  return (
    <FormControl>
      <Input 
        id="registration_token"
        aria-describedby="registration_token-helper-text"
        value={registrationToken}
        onChange={(e) => {setRegistrationToken(e.target.value)}} />
      <FormHelperText 
        id="registration_token-helper-text">
        Registration token given by a gamenight admin
      </FormHelperText>

      <Input 
        id="username"
        aria-describedby="email-helper-text"
        value={username}
        onChange={(e) => {setUsername(e.target.value)}} />
      <FormHelperText 
        id="username-helper-text">
        Username to display everywhere
      </FormHelperText>

      <Input 
        id="email"
        aria-describedby="email-helper-text"
        value={email}
        onChange={(e) => {setEmail(e.target.value)}} />
      <FormHelperText 
        id="email-helper-text">
        E-mail used for notifications and password resets
      </FormHelperText>

      <Input 
        id="password"
        type="password"
        aria-describedby="password-helper-text"
        value={password}
        onChange={(e) => {setPassword(e.target.value)}} />
      <FormHelperText 
        id="password-helper-text">
        Password atleast 10 characters long
      </FormHelperText>

      <Input
        id="password_repeat"
        type="password"
        aria-describedby="password_repeat-helper-text"
        value={passwordRepeat}
        onChange={(e) => {setPasswordRepeat(e.target.value)}} />
      <FormHelperText
        id="password_repeat-helper-text">
        Confirm your password
      </FormHelperText>

      <Button 
        variant="outlined"
        color="success"
        onClick={onRegister}>
        Register
      </Button>

    </FormControl>

  );
}

export default Register;